@@ -1,3 +1,3 @@
-from .db import connect, connect_database
+from .db import connect, connect_database, Mode
 from .copy import copy
 from .cache import MongoCache
