@@ -50,7 +50,8 @@ def uri_connect(host: str = 'localhost', port: int = 27017, replicaset: str = No
     if mode not in [Mode.AWS_Lambda, Mode.ECS_Container, Mode.EC2_Instance]:
         uri += f'{user}' if user else ''
         uri += f':{password}' if password else ''
-    uri += f'@{host}'
+    host = host if host.endswith('/') else f'{host}/'
+    uri += f'@{host}' if user and mode not in [Mode.MONGODB_AWS] else host
     if mode and mode.value:
         uri += f'?authMechanism={mode.value}' + \
             (f'&authSource={database}' if database else '') + \
@@ -130,11 +131,11 @@ def connect_database(host: str = 'localhost', port: int = 27017, replicaset: str
     :param session_token: The session token to use.
     :return: The MongoDB client.
     """
+    if not user or mode == Mode.NONE:
+        return uri_connect(host, port, replicaset, database, mode=Mode.NONE)
     if mode == Mode.AUTO:
         return detect_connection(host, port, replicaset, database,
                                  user, password, cert_key_file, ca_file, session_token)
-    if not user or mode == Mode.NONE:
-        return uri_connect(host, port, replicaset, database, mode=mode)
     if mode in [Mode.MONGODB_X509, Mode.GSSAPI]:
         return uri_connect(host, port, replicaset, database, user, None, mode, cert_key_file, ca_file, session_token)
     if mode in [Mode.SCRAM_SHA_256, Mode.SCRAM_SHA_1]:
@@ -157,15 +158,12 @@ def detect_connection(host: str = 'localhost', port: int = 27017, replicaset: st
     :param session_token: The session token to use.
     :return: The MongoDB client.
     """
-    error = None
     for mode in list(Mode)[2:]:
         try:
             client = connect_database(host, port, replicaset, database,
                                       user, password, mode, cert_key_file, ca_file, session_token)
             client.list_database_names()
             return client
-        except ServerSelectionTimeoutError as e:
-            error = error if error else e
-        except OperationFailure as e:
-            error = OperationFailure('Authentication error')
-    raise error
+        except (ServerSelectionTimeoutError, OperationFailure) as e:
+            pass
+    raise OperationFailure('Authentication error')
